==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/acl/lang/ja/lang.php <==
<?php
/**
 * japanese language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Davilin(Yuji Takenaka) <webmaster@davilin.com>
 * @author Yuji Takenaka <webmaster@davilin.com>
 * @author Ikuo Obataya <i.obataya@gmail.com>
 * @author Daniel Dupriest <kououken@gmail.com>
 * @author Kazutaka Miyasaka <kazmiya@gmail.com>
 * @author Taisuke Shimamoto <dentostar@gmail.com>
 * @author Satoshi Sahara <sahara.satoshi@gmail.com>
 */
$lang['admin_acl']             = 'アクセスコントロール管理';
$lang['acl_group']             = 'グループ';
$lang['acl_user']              = 'ユーザー';
$lang['acl_perms']             = '権限を追加';
$lang['page']                  = '文書';
$lang['namespace']             = '名前空間';
$lang['btn_select']            = '選択';
$lang['p_user_id']             = 'ユーザー <b class="acluser">%s</b> は、ページ <b class="aclpage">%s</b> に対して次の権限を持っています: <i>%s</i>';
$lang['p_user_ns']             = 'ユーザー <b class="acluser">%s</b> は、名前空間 <b class="aclns">%s</b> に対して次の権限を持っています: <i>%s</i>';
$lang['p_group_id']            = 'グループ <b class="aclgroup">%s</b> のメンバーは、ページ <b class="aclpage">%s</b> に対して次の権限を持っています: <i>%s</i>';
$lang['p_group_ns']            = 'グループ <b class="aclgroup">%s</b> のメンバーは、名前空間 <b class="aclns">%s</b> に対して次の権限を持っています: <i>%s</i>';
$lang['p_choose_id']           = 'ページ <b class="aclpage">%s</b> にセットされた権限を閲覧・編集するためには、上記のフォームに<b>ユーザー名もしくはグループ名を入力して下さい</b>。';
$lang['p_choose_ns']           = '名前空間 <b class="aclns">%s</b> にセットされた権限を閲覧・編集するためには、上記のフォームに<b>ユーザー名もしくはグループ名を入力して下さい</b>。';
$lang['p_inherited']           = '注意：これらの権限は明示されていませんが、他のグループもしくは上位の名前空間の権限を継承します。';
$lang['p_isadmin']             = '注意：選択したグループもしくはユーザーはスーパーユーザーであるため、全ての権限があります。';
$lang['p_include']             = '高次の権限は、それより低次の権限を含みます。作成・アップロード・削除の権限は、ページではなく名前空間のみに適用されます。';
$lang['current']               = '現在のACLルール';
$lang['where']                 = 'ページ/名前空間';
$lang['who']                   = 'ユーザー/グループ';
$lang['perm']                  = '権限';
$lang['acl_perm0']             = '無し';
$lang['acl_perm1']             = '読取';
$lang['acl_perm2']             = '編集';
$lang['acl_perm4']             = '作成';
$lang['acl_perm8']             = 'アップロード';
$lang['acl_perm16']            = '削除';
$lang['acl_new']               = '新規エントリ';
$lang['acl_mod']               = 'エントリの編集';

==> dokuwiki-2014.09.29b.tgz: dokuwiki/lib/plugins/acl/lang/ja/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Davilin(Yuji Takenaka) <webmaster@davilin.com>
 * @author Yuji Takenaka <webmaster@davilin.com>
 * @author Ikuo Obataya <i.obataya@gmail.com>
 * @author Daniel Dupriest <kououken@gmail.com>
 * @author Kazutaka Miyasaka <kazmiya@gmail.com>
 * @author Taisuke Shimamoto <dentostar@gmail.com>
 * @author Satoshi Sahara <sahara.satoshi@gmail.com>
 */
$lang['admin_acl']             = 'アクセスコントロール管理';
$lang['acl_group']             = 'グループ:';
$lang['acl_user']              = 'ユーザー:';
$lang['acl_perms']             = '権限を追加';
$lang['page']                  = '文書';
$lang['namespace']             = '名前空間';
$lang['btn_select']            = '選択';
$lang['p_user_id']             = 'ユーザー <b class="acluser">%s</b> は、ページ <b class="aclpage">%s</b> に対して次の権限を持っています: <i>%s</i>';
$lang['p_user_ns']             = 'ユーザー <b class="acluser">%s</b> は、名前空間 <b class="aclns">%s</b> に対して次の権限を持っています: <i>%s</i>';
$lang['p_group_id']            = 'グループ <b class="aclgroup">%s</b> のメンバーは、ページ <b class="aclpage">%s</b> に対して次の権限を持っています: <i>%s</i>';
$lang['p_group_ns']            = 'グループ <b class="aclgroup">%s</b> のメンバーは、名前空間 <b class="aclns">%s</b> に対して次の権限を持っています: <i>%s</i>';
$lang['p_choose_id']           = 'ページ <b class="aclpage">%s</b> にセットされた権限を閲覧・編集するためには、上記のフォームに<b>ユーザー名もしくはグループ名を入力して下さい</b>。';
$lang['p_choose_ns']           = '名前空間 <b class="aclns">%s</b> にセットされた権限を閲覧・編集するためには、上記のフォームに<b>ユーザー名もしくはグループ名を入力して下さい</b>。';
$lang['p_inherited']           = '注意：これらの権限は明示されていませんが、他のグループもしくは上位の名前空間の権限を継承します。';
$lang['p_isadmin']             = '注意：選択したグループもしくはユーザーはスーパーユーザーであるため、全ての権限があります。';
$lang['p_include']             = '高次の権限は、それより低次の権限を含みます。作成・アップロード・削除の権限は、ページではなく名前空間のみに適用されます。';
$lang['current']               = '現在のACLルール';
$lang['where']                 = 'ページ/名前空間';
$lang['who']                   = 'ユーザー/グループ';
$lang['perm']                  = '権限';
$lang['acl_perm0']             = '無し';
$lang['acl_perm1']             = '読取';
$lang['acl_perm2']             = '編集';
$lang['acl_perm4']             = '作成';
$lang['acl_perm8']             = 'アップロード';
$lang['acl_perm16']            = '削除';
$lang['acl_new']               = '新規エントリ';
$lang['acl_mod']               = 'エントリの編集';
